addRangeToBottom method
Adds a range of items to the bottom of the list.
Implementation
void addRangeToBottom(List<T> items) {
_newItems.addAll(items);
_lastAddedToBottom = true;
notifyListeners();
}
Adds a range of items to the bottom of the list.
void addRangeToBottom(List<T> items) {
_newItems.addAll(items);
_lastAddedToBottom = true;
notifyListeners();
}