addRangeToTop method
Adds a range of items to the top of the list.
Implementation
void addRangeToTop(List<T> items) {
_oldItems.addAll(items);
_lastAddedToBottom = false;
notifyListeners();
}
Adds a range of items to the top of the list.
void addRangeToTop(List<T> items) {
_oldItems.addAll(items);
_lastAddedToBottom = false;
notifyListeners();
}