addToBottom method
void
addToBottom(
- T item
Adds an item to the bottom of the list.
Implementation
void addToBottom(T item) {
_newItems.add(item);
_lastAddedToBottom = true;
notifyListeners();
}
Adds an item to the bottom of the list.
void addToBottom(T item) {
_newItems.add(item);
_lastAddedToBottom = true;
notifyListeners();
}