setDidLoadAll method

void setDidLoadAll(
  1. bool value
)

Sets the value of _didLoadAll. If set to true, the load more callback will not be called anymore. This is used automatically and should not be called manually unless for specific use cases.

Implementation

void setDidLoadAll(bool value) => _didLoadAll = value;