ChatListItemProperties class

A class that contains properties of a chat list item. It is used in the itemBuilder of the ChatList widget.

Constructors

ChatListItemProperties({required int index, required int localIndex, required bool isInNew, required bool isAtTopEdge, required bool isAtBottomEdge})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The index of the item in the list. If index equals to 0, it is the first item from the bottom in the list.
final
isAtBottomEdge bool
Determines if the item is at the bottom edge of the list.
final
isAtEdge bool
Determines if the item is at the edge of the list.
no setter
isAtTopEdge bool
Determines if the item is at the top edge of the list.
final
isInNew bool
Determines if the item is in the new items range.
final
localIndex int
The local index of the item in new or old items range. The old items are the items that are initially loaded in the list and loaded from the load more callback. The new items are the items that are added to the bottom of the list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited