lorien_chat_list library
Classes
-
ChatList<
T> -
ChatListController<
T> - A controller for a ChatList widget. It is used to manage the items of the list and to notify the list when changes occur.
- ChatListItemProperties
-
A class that contains properties of a chat list item.
It is used in the
itemBuilderof theChatListwidget.